@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.9"
+__version__ = "1.1.0"
 
 import argparse
 import base64
@@ -189,8 +189,12 @@ def main():
     # Add argument for the auth token
     parser.add_argument('-t', help='Auth token', required=False)
 
+    parser.add_argument('-o', help='Orgnization prefix', required=False)
+
     args = parser.parse_args()
     project_id = args.p
+    prefix = args.o
+
     print("Project ID: %s" % project_id)
     # Check if user wrote the -u argument
     if args.u:
@@ -219,8 +223,11 @@ def main():
                     git_url_input = git_url_input.strip()
 
                     if '/' not in git_url_input:
-                        # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
-                        git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
+                        # Single Project ID given, add prefix 'MeshMonitors-Remote-1/' if no -o argument is given
+                        if prefix is None:
+                            git_url_input = 'MeshMonitors-Remote-1/' + git_url_input
+                        else:
+                            git_url_input = prefix + '/' + git_url_input
 
                     if git_url_input is not None:
                         is_empty = os.listdir(os.getcwd()) == []
@@ -267,9 +274,11 @@ def main():
                 git_url_input = git_url_input.strip()
 
                 if '/' not in git_url_input:
-
                     # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
-                    git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
+                    if prefix is None:
+                        git_url_input = 'MeshMonitors-Remote-1/' + git_url_input
+                    else:
+                        git_url_input = prefix + '/' + git_url_input
 
                 if git_url_input is not None:
                     is_empty = os.listdir(os.getcwd()) == []
